Contributing to development
===========================

The |MESSAGEix| software stack, including :mod:`ixmp` and :mod:`message_ix`, is developed by a single group of contributors in an integrated process.
The MESSAGEix documentation contains :doc:`complete guidelines <message_ix:contributing>` for contributing to the code base, at: https://docs.messageix.org/en/latest/contributing.html.
All of these guidelines apply to :mod:`ixmp`.

Contributors who have signed the contributor license agreement (CLA) for |MESSAGEix| will need to separately sign the (identical) :doc:`CLA for ixmp <contributor_license>` when making their first pull request to :mod:`ixmp`.
